@@ -48,6 +48,10 @@ class Solution(Aqueous):
     _visc = 1E-3           # Dynamic viscosity (water)  [Pa s]
     _Adh = 0.512           # L^1/2 / mol^1/2, approximate for room temperature
     _aD = 1.5              # mol^-1/2 mol^-3/2, approximation
+    _permittivity = 8.85e-12   # permittivity of free space
+    _k = 1.38e-23              # Boltzman constant
+    _Na = 6.02e23          # Avagadro's number
+    _e = 1.6e-19               # elementary charge
 
     _H = Ion('H+', [1], [100], [362E-9])
     _OH = Ion('OH-', [-1], [-100], [-205E-9])
@@ -114,6 +118,9 @@ class Solution(Aqueous):
         self._H.actual_mobility = [actual_mobilities[-1][0]]
         self._OH.actual_mobility = [actual_mobilities[-1][1]]
 
+    def set_T(self, T):
+        return Solution(self.ions, self.concentrations, T=T)
+
     def adjust_Kw(self):
         pKw_ref = -log10(self._Kw_ref)
         T_ref = self._T_ref + 273.15
@@ -182,9 +189,18 @@ class Solution(Aqueous):
         Corrects for the mobility of the ion using the
         ion object's actual mobility.
         """
-        OH_conductivity = self.cOH()*self._OH.molar_conductivity(self.pH, self.I)
+        OH_conductivity = self.cOH() *\
+            self._OH.molar_conductivity(self.pH, self.I)
+
         return OH_conductivity
 
+    def debye(self):
+        dielectric = self._dielectric(self.T)
+        viscosity = self._viscosity(self.T)
+        epsilon = dielectric * self._permittivity
+        lamda = (epsilon*self._k*self.T/self._e**2/self.I/self._Na)**.5
+        return lamda
+
     def __add__(self, other):
         new_i = self.ions[:]
         new_c = self.concentrations[:]
@@ -196,8 +212,10 @@ class Solution(Aqueous):
                     new_i.append(ion)
                     new_c.append(c)
             return Solution(new_i, new_c)
-        elif isinstance(other, (list, tuple)) and len(other) == 2 and\
-                isinstance(other[0], Ion) and isinstance(other[1], (int, float)):
+        elif isinstance(other, (list, tuple)) and\
+                len(other) == 2 and\
+                isinstance(other[0], Ion) and\
+                isinstance(other[1], (int, float)):
             ion, c = other
             if ion in self.ions:
                 new_c[self.ions.index(ion)] += c
